#
# spec file for package python-markdown-it-py
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-markdown-it-py
VCS: https://src.suse.de/SLFO-pool/python-markdown-it-py#35cba3c3db92c33666f785b07dd39ceb3a76c635efec01014b7dc558569f49d4
Version:        3.0.0
Release:        160000.1.9
Summary:        Python port of markdown-it Markdown parsing
License:        MIT
URL:            https://github.com/executablebooks/markdown-it-py/
Source:         https://github.com/executablebooks/markdown-it-py/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
#Source:         https://files.pythonhosted.org/packages/source/m/markdown-it-py/markdown-it-py-%%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module mdurl}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
# SECTION tests
BuildRequires:  %{python_module linkify-it-py}
BuildRequires:  %{python_module pytest-regressions}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-mdurl
Requires(post): update-alternatives
Requires(postun):update-alternatives
Suggests:       python-mdit-py-plugins
BuildArch:      noarch
%python_subpackages

%description
This is a Python port of [markdown-it], and some of its associated plugins.

It follows the CommonMark spec for baseline parsing, has a configurable syntax and is pluggable.

%prep
%autosetup -p1 -n markdown-it-py-%{version}
sed -i '1{/\/usr\/bin\/env python*/d;}' markdown_it/cli/parse.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/markdown-it
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%post
%python_install_alternative markdown-it

%postun
%python_uninstall_alternative markdown-it

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE LICENSE.markdown-it
%{python_sitelib}/markdown_it
%{python_sitelib}/markdown_it_py-%{version}.dist-info
%python_alternative %{_bindir}/markdown-it

%changelog
* Thu Nov 23 2023 daniel.garcia@suse.com
- Update to version 3.0.0:
  * drop python 3.7 support
  * Update from upstream markdown-it 12.2.0 to 13.0.0
  - A key change is the addition of a new Token type, text_special,
    which is used to represent HTML entities and backslash escaped
    characters.
  - This ensures that (core) typographic transformation rules are not
    incorrectly applied to these texts.
  - The final core rule is now the new text_join rule, which joins
    adjacent text/text_special tokens, and so no text_special tokens
    should be present in the final token stream.
  - Any custom typographic rules should be inserted before text_join.
  - A new linkify rule has also been added to the inline chain, which
    will linkify full URLs (e.g. https://example.com), and fixes
    collision of emphasis and linkifier (so
    http://example.org/foo._bar_-_baz is now a single link, not
    emphasized).
  - Emails and fuzzy links are not affected by this.
  * REFACTOR: Replace most character code use with strings
  - The use of StateBase.srcCharCode is deprecated (with
    backward-compatibility), and all core uses are replaced by
    StateBase.src.
  - Conversion of source string characters to an integer
    representing the Unicode character is prevalent in the upstream
    JavaScript implementation, to improve performance. However, it
    is unnecessary in Python and leads to harder to read code and
    performance deprecations (during the conversion in the StateBase
    initialisation).
  * Centralise indented code block tests
  - For CommonMark, the presence of indented code blocks prevent any
    other block element from having an indent of greater than 4
    spaces.
  - Certain Markdown flavors and derivatives, such as mdx and djot,
    disable these code blocks though, since it is more common to use
    code fences and/or arbitrary indenting is desirable.
  - Previously, disabling code blocks did not remove the indent
    limitation, since most block elements had the 3 space limitation
    hard-coded.
  - This change centralised the logic of applying this limitation
    (in StateBlock.is_code_block), and only applies it when indented
    code blocks are enabled.
  * Maintenance changes
  - Strict type annotation checking has been applied to the whole
    code base, ruff is now used for linting, and fuzzing tests have
    been added to the CI, to integrate with Google OSS-Fuzz testing,
    thanks to @DavidKorczynski.
* Fri May  5 2023 kastl@b1-systems.de
- add sle15_python_module_pythons
* Mon Mar  6 2023 sebix@sebix.at
- update to version 2.2.0:
  - What's Changed:
  - UPGRADE: Allow linkify-it-py v2
  - FIX: CVE-2023-26303, fix boo#1208974
  - FIX: CLI crash on non-utf8 character
  - DOCS: Add section about markdown renderer
  - Update benchmark pkg versions
* Mon Sep  5 2022 eroca@mailbox.org
- Cleanup requirements, tests, files section and comments
* Tue Apr 26 2022 sebix+novell.com@sebix.at
- initial package for version 2.1.0.
